All platforms.

net.eighttrigrams.cljs-text-editor.test-helpers


convertclj/s

(convert s)
source

matches-modelclj/s

(matches-model map1 model)

Tests if map1 has al the keys the model has, and then tests if those keys have the corresponding values. map1 may have additional values not specified in model

Tests if map1 has al the keys the model has,
and then tests if those keys have the corresponding values.
map1 may have additional values not specified in model
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries